@@ -1,5 +1,7 @@
 package Data::Faker::PhoneNumber;
-use vars qw($VERSION); $VERSION = '0.09';
+use strict;
+use warnings;
+use vars qw($VERSION); $VERSION = '0.10';
 use base 'Data::Faker';
 
 =head1 NAME
